@@ -1,20 +1,7 @@
 /*
-    Copyright (c) 2009 Andras Mantia <amantia@kde.org>
+    SPDX-FileCopyrightText: 2009 Andras Mantia <amantia@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KIMAP_METADATAJOBBASE_H
@@ -26,7 +13,6 @@
 
 namespace KIMAP
 {
-
 class Session;
 struct Response;
 class MetaDataJobBasePrivate;
@@ -36,15 +22,15 @@ class MetaDataJobBasePrivate;
  *
  * Provides support for the IMAP METADATA extension; both the
  * final RFC version
- * (<a href="http://tools.ietf.org/html/rfc5464">RFC 5464</a>)
+ * (<a href="https://tools.ietf.org/html/rfc5464">RFC 5464</a>)
  * and the older, incompatible draft version (known as ANNOTATEMORE)
  * (<a
- * href="http://tools.ietf.org/html/draft-daboo-imap-annotatemore-07"
+ * href="https://tools.ietf.org/html/draft-daboo-imap-annotatemore-07"
  * >draft-daboo-imap-annotatemore-07</a>).
  *
  * This class cannot be used directly, you must subclass it and reimplement
  * at least the doStart() method.
-*/
+ */
 class KIMAP_EXPORT MetaDataJobBase : public Job
 {
     Q_OBJECT
@@ -92,7 +78,7 @@ public:
      *
      * @return  a mailbox name, or an empty string
      */
-    QString mailBox() const;
+    Q_REQUIRED_RESULT QString mailBox() const;
 
     /**
      * Set what version of the metadata extension to be compatible with.
@@ -115,11 +101,10 @@ public:
     /**
      * The version of the metadata extension that will be used.
      */
-    ServerCapability serverCapability() const;
+    Q_REQUIRED_RESULT ServerCapability serverCapability() const;
 
 protected:
     MetaDataJobBase(JobPrivate &dd);
-
 };
 
 }
